Skip to main contentModule plugin
Source - Plugin
- PushResponse
- What a plugin returns on stdout after a successful
push.
Core stores this verbatim into task.external.{plugin_name}. - SyncCreate
- A new task to create locally, reported by plugin sync.
- SyncDelete
- A local task to mark as deferred.
- SyncReport
- Full sync report returned by the plugin on stdout after
sync. - SyncUpdate
- Fields to update on an existing local task.
- apply_push_response
- Merge push results into task.external and save+commit.
- run_plugin_push
- Run plugin push for all active plugins. Returns a map of
plugin_name -> PushResponse for plugins that returned data.
- run_plugin_sync
- Run plugin sync for all active plugins. Returns (plugin_name, SyncReport) pairs.